@@ -7,6 +7,9 @@ from .hooks import (HOOKS, CheckpointHook, ClosureHook, DistSamplerSeedHook,
                     OptimizerHook, PaviLoggerHook, TensorboardLoggerHook,
                     TextLoggerHook, WandbLoggerHook)
 from .log_buffer import LogBuffer
+from .optimizer import (OPTIMIZER_BUILDERS, OPTIMIZERS,
+                        DefaultOptimizerConstructor, build_optimizer,
+                        build_optimizer_constructor)
 from .priority import Priority, get_priority
 from .runner import Runner
 from .utils import get_host_info, get_time_str, obj_from_dict
@@ -18,5 +21,7 @@ __all__ = [
     'WandbLoggerHook', '_load_checkpoint', 'load_state_dict',
     'load_checkpoint', 'weights_to_cpu', 'save_checkpoint', 'Priority',
     'get_priority', 'get_host_info', 'get_time_str', 'obj_from_dict',
-    'init_dist', 'get_dist_info', 'master_only'
+    'init_dist', 'get_dist_info', 'master_only', 'OPTIMIZER_BUILDERS',
+    'OPTIMIZERS', 'DefaultOptimizerConstructor', 'build_optimizer',
+    'build_optimizer_constructor'
 ]
